@@ -1,8 +1,8 @@
 
 /*
- *  agInit.c  $Id: agInit.c,v 4.12 2007/08/05 17:09:50 bkorb Exp $
+ *  agInit.c  $Id: agInit.c,v 4.17 2007/12/02 23:13:15 bkorb Exp $
  *
- *  Time-stamp:      "2007-07-04 11:14:11 bkorb"
+ *  Time-stamp:      "2007-12-02 15:02:27 bkorb"
  *
  *  Do all the initialization stuff.  For daemon mode, only
  *  children will return.
@@ -116,8 +116,37 @@ initialize( int arg_ct, char** arg_vec )
 #endif
     }
 
-#ifndef DAEMON_ENABLED
-    doOptions( arg_ct, arg_vec );
+    {
+        static char const bin_sh[] = "/bin/sh";
+#       define sh_z (bin_sh + 5)
+
+        pzShellProgram = getenv(zShellEnv);
+
+        if (pzShellProgram != NULL) {
+            char const * pzCsh = pzShellProgram;
+            pzCsh += strlen(pzCsh) - 3;
+            if ((pzCsh >= pzShellProgram) &&
+                (strcmp(pzCsh, "csh") == 0))
+                pzShellProgram = NULL;
+        }
+
+        if (pzShellProgram == NULL) {
+#           ifdef __sun
+            static char const xpg_sh[] = "/usr/xpg4/bin/sh";
+
+            if (access(xpg_sh, X_OK) == 0)
+                pzShellProgram = xpg_sh;
+            else
+#           endif
+                if (access(bin_sh, X_OK) == 0)
+                    pzShellProgram = bin_sh;
+                else pzShellProgram = sh_z;
+
+        }
+        putenv( aprf("%s=%s", zShellEnv, pzShellProgram));
+    }
+
+    doOptions(arg_ct, arg_vec);
 
     if (OPT_VALUE_TRACE > TRACE_NOTHING) {
         tSCC zBT[] = "(debug-enable 'backtrace)";
@@ -125,15 +154,7 @@ initialize( int arg_ct, char** arg_vec )
         ag_scm_c_eval_string_from_file_line( zBT, __FILE__, __LINE__ - 2 );
     }
 
-#else
-    optionSaveState( &autogenOptions );
-    doOptions( arg_ct, arg_vec );
-
-    if (OPT_VALUE_TRACE > TRACE_NOTHING) {
-        tSCC zBT[] = "(debug-enable 'backtrace)";
-        pzLastScheme = zBT;
-        ag_scm_c_eval_string_from_file_line( zBT, __FILE__, __LINE__ - 2 );
-    }
+#ifdef DAEMON_ENABLED
 
     if (! HAVE_OPT( DAEMON ))
         return;
@@ -168,9 +189,9 @@ addSysEnv( char* pzEnvName )
     int i = 2;
 
     for (;;) {
-        if (isupper( pzEnvName[i] ))
-            pzEnvName[i] = tolower( pzEnvName[i] );
-        else if (! isalnum( pzEnvName[i] ))
+        if (IS_UPPER_CASE_CHAR(pzEnvName[i]))
+            pzEnvName[i] = tolower(pzEnvName[i]);
+        else if (! IS_ALPHANUMERIC_CHAR(pzEnvName[i]))
             pzEnvName[i] = '_';
 
         if (pzEnvName[ ++i ] == NUL)
@@ -184,7 +205,7 @@ addSysEnv( char* pzEnvName )
     if (getenv( pzEnvName ) == NULL) {
         char* pz;
 
-        if (OPT_VALUE_TRACE > TRACE_NOTHING)
+        if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
             fprintf( pfTrace, "Adding ``%s'' to environment\n", pzEnvName );
         pz = aprf( zFmt, pzEnvName );
         TAGMEM( pz, "Added environment var" );
@@ -200,7 +221,7 @@ evalProto( tCC** ppzS, uint16_t* pProto )
 {
     tCC* pzS = *ppzS;
 
-    if (isalpha( *pzS )) {
+    if (IS_ALPHABETIC_CHAR(*pzS)) {
         inet_family_map_t* pMap = inet_family_map;
         do  {
             if (strncmp( pzS, pMap->pz_name, pMap->nm_len ) == 0) {
@@ -211,7 +232,7 @@ evalProto( tCC** ppzS, uint16_t* pProto )
         } while ( (++pMap)->pz_name != NULL );
     }
 
-    return isdigit( *pzS );
+    return IS_DEC_DIGIT_CHAR(*pzS);
 }
 
 
