@@ -1,31 +1,27 @@
 /*
  *  agShell
- *  $Id: agShell.c,v 4.20 2007/04/28 22:19:23 bkorb Exp $
+ *  $Id: agShell.c,v 4.26 2007/11/15 19:51:24 bkorb Exp $
  *
- *  Time-stamp:        "2006-11-26 15:09:07 bkorb"
- *  Last Committed:    $Date: 2007/04/28 22:19:23 $
+ *  Time-stamp:        "2007-11-12 22:27:11 bkorb"
+ *  Last Committed:    $Date: 2007/11/15 19:51:24 $
  *
  *  Manage a server shell process
- */
-
-/*
- *  AutoGen copyright 1992-2007 Bruce Korb
  *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * AutoGen is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ * AutoGen is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef SHELL_ENABLED
@@ -59,7 +55,7 @@ tSCC   zCmdFmt[]   = "cd %s\n%s\n\necho\necho %s - %d\n";
 char const* pzLastCmd = NULL;
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static void
 sigHandler( int signo );
 
@@ -239,41 +235,7 @@ chainOpen( int       stdinFd,
     if (pzShell = *ppArgs,
        (pzShell == NULL) || (*pzShell == NUL)) {
 
-        if (pzShellProgram != NULL)
-            pzShell = pzShellProgram;
-
-        else {
-            static char const sh_z[] = "sh";
-            static char const bin_sh[] = "/bin/sh";
-
-            pzShellProgram = getenv( zShellEnv );
-            if (pzShellProgram == NULL) {
-#               ifdef __sun
-                static char const xpg_sh[] = "/usr/xpg4/bin/sh";
-#               endif
-
-            no_useful_SHELL:
-#               ifdef __sun
-                if (access(xpg_sh, X_OK) == 0)
-                    pzShellProgram = xpg_sh;
-                else
-#               endif
-                    if (access(bin_sh, X_OK) == 0)
-                         pzShellProgram = bin_sh;
-                    else pzShellProgram = sh_z;
-
-            } else {
-                char const * pze = pzShellProgram + strlen(pzShellProgram);
-                if (  ((pze - pzShellProgram) > 2)
-                   && (pze[-3] == 'c')
-                   && (pze[-2] == 's')
-                   && (pze[-1] == 'h'))  {
-                    goto no_useful_SHELL;
-                }
-            }
-            putenv( aprf( "%s=%s", zShellEnv, pzShellProgram ));
-            pzShell = pzShellProgram;
-        }
+        pzShell = pzShellProgram;
 
         *ppArgs = pzShell;
     }
@@ -510,7 +472,7 @@ loadData( void )
      *  Trim off all trailing white space and shorten the buffer
      *  to the size actually used.
      */
-    while ((pzScan > pzText) && isspace( pzScan[-1] )) pzScan--;
+    while ((pzScan > pzText) && IS_WHITESPACE_CHAR(pzScan[-1])) pzScan--;
     textSize = (pzScan - pzText) + 1;
 
     if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL) {
