@@ -1,32 +1,28 @@
 
 /*
  *  autogen.c
- *  $Id: autogen.c,v 4.21 2007/03/25 16:48:11 bkorb Exp $
+ *  $Id: autogen.c,v 4.26 2007/12/02 22:41:59 bkorb Exp $
  *
- *  Time-stamp:        "2007-03-25 07:47:12 bkorb"
- *  Last Committed:    $Date: 2007/03/25 16:48:11 $
+ *  Time-stamp:        "2007-12-02 12:06:21 bkorb"
+ *  Last Committed:    $Date: 2007/12/02 22:41:59 $
  *
  *  This is the main routine for autogen.
- */
-
-/*
- *  AutoGen copyright 1992-2007 Bruce Korb
  *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * AutoGen is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ * AutoGen is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 tSCC zClientInput[] = "client-input";
@@ -42,7 +38,7 @@ typedef void (sighandler_proc_t)( int sig );
 static sighandler_proc_t ignoreSignal, abendSignal;
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static void
 inner_main( int argc, char** argv );
 
@@ -92,11 +88,10 @@ inner_main( int argc, char** argv )
     exit( EXIT_SUCCESS );
 }
 
-
 int
-main( int    argc,
-      char** argv )
+main(int argc, char** argv)
 {
+    optionSaveState(&autogenOptions);
     pfTrace = stderr;
 
     /*
@@ -224,7 +219,7 @@ doneCheck( void )
 #ifdef SHELL_ENABLED
     ag_scm_c_eval_string_from_file_line(
         "(if (> (string-length shell-cleanup) 0)"
-        " (shell shell-cleanup) )", __FILE__, __LINE__ );
+        " (shell shell-cleanup) )", __FILE__, __LINE__ - 1 );
     closeServer();
 #endif
 
@@ -232,7 +227,7 @@ doneCheck( void )
     fflush( stderr );
 
     if (pfTrace != stderr ) {
-        if (* OPT_ARG( TRACE_OUT ) == '|') {
+        if (trace_is_to_pipe) {
             int status;
 
             pclose( pfTrace );
@@ -361,9 +356,9 @@ ag_abend_at( tCC* pzMsg
 #endif
 
     if ((procState >= PROC_STATE_LIB_LOAD) && (pCurTemplate != NULL)) {
-        int line = (pCurMacro == NULL) ? -1 : pCurMacro->lineNo;
+        int l_no = (pCurMacro == NULL) ? -1 : pCurMacro->lineNo;
         fprintf( stderr, "Error in template %s, line %d\n\t",
-                 pCurTemplate->pzTplFile, line );
+                 pCurTemplate->pzTplFile, l_no );
     }
     fputs( pzMsg, stderr );
     pzMsg += strlen( pzMsg );
@@ -427,6 +422,13 @@ signalSetup( sighandler_proc_t* chldHandler,
              */
         case SIGKILL:
         case SIGSTOP:
+
+            /*
+             *  Signals we choose to leave alone.
+             */
+#ifdef SIGTSTP
+        case SIGTSTP:
+#endif
             continue;
 
 #if defined(DEBUG_ENABLED)
@@ -447,9 +449,6 @@ signalSetup( sighandler_proc_t* chldHandler,
 #ifdef SIGWINCH
         case SIGWINCH:
 #endif
-#ifdef SIGTSTP
-        case SIGTSTP:  /* suspended  */
-#endif
 #ifdef SIGTTIN
         case SIGTTIN:  /* tty input  */
 #endif
