@@ -1,13 +1,13 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (cgi-fsm.c)
  *  
- *  It has been AutoGen-ed  Saturday May  5, 2007 at 12:03:05 PM PDT
+ *  It has been AutoGen-ed  Sunday December 23, 2007 at 01:03:27 PM PST
  *  From the definitions    cgi.def
  *  and the template file   fsm
  *
  *  Automated Finite State Machine
  *
- *  Copyright (c) 2001-2007  by  Bruce Korb
+ *  copyright (c) 2001-2007 by Bruce Korb - all rights reserved
  *
  *  AutoFSM is free software copyrighted by Bruce Korb.
  *  
@@ -38,6 +38,7 @@
 #define DEFINE_FSM
 #include "cgi-fsm.h"
 #include <stdio.h>
+#include <ctype.h>
 
 /*
  *  Do not make changes to this file, except between the START/END
@@ -186,9 +187,6 @@ cgi_run_fsm(
 {
     te_cgi_state cgi_state = CGI_ST_INIT;
     te_cgi_event trans_evt;
-#ifdef DEBUG
-    te_cgi_state firstNext;
-#endif
     te_cgi_state nxtSt;
     te_cgi_trans trans;
 
@@ -229,19 +227,10 @@ cgi_run_fsm(
         } else {
             const t_cgi_transition* pTT =
             cgi_trans_table[ cgi_state ] + trans_evt;
-#ifdef DEBUG
-            firstNext = /* next line */
-#endif
             nxtSt = pTT->next_state;
             trans = pTT->transition;
         }
 
-#ifdef DEBUG
-        printf( "in state %s(%d) step %s(%d) to %s(%d)\n",
-            CGI_STATE_NAME( cgi_state ), cgi_state,
-            CGI_EVT_NAME( trans_evt ), trans_evt,
-            CGI_STATE_NAME( nxtSt ), nxtSt );
-#endif
 
         switch (trans) {
         case CGI_TR_INVALID:
@@ -311,11 +300,7 @@ cgi_run_fsm(
             exit( cgi_invalid_transition( cgi_state, trans_evt ));
             /* END   == BROKEN MACHINE == DO NOT CHANGE THIS COMMENT */
         }
-#ifdef DEBUG
-        if (nxtSt != firstNext)
-            printf( "transition code changed destination state to %s(%d)\n",
-                CGI_STATE_NAME( nxtSt ), nxtSt );
-#endif
+
         cgi_state = nxtSt;
     }
     return cgi_state;
