@@ -1,9 +1,9 @@
 
 /*
- *  $Id: expOutput.c,v 4.25 2007/08/05 17:09:50 bkorb Exp $
+ *  $Id: expOutput.c,v 4.30 2007/12/10 20:03:09 bkorb Exp $
  *
- *  Time-stamp:        "2007-07-04 11:19:28 bkorb"
- *  Last Committed:    $Date: 2007/08/05 17:09:50 $
+ *  Time-stamp:        "2007-12-05 06:19:49 bkorb"
+ *  Last Committed:    $Date: 2007/12/10 20:03:09 $
  *
  *  This module implements the output file manipulation function
  *
@@ -116,7 +116,8 @@ ag_scm_out_delete( void )
     /*
      *  Delete the current output file
      */
-    fprintf( pfTrace, zSkipMsg, pCurFp->pzOutName );
+    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+        fprintf( pfTrace, zSkipMsg, pCurFp->pzOutName );
     outputDepth = 1;
     longjmp( fileAbort, PROBLEM );
     /* NOTREACHED */
@@ -142,7 +143,9 @@ ag_scm_out_move( SCM new_file )
     memcpy( pz, AG_SCM_CHARS( new_file ), sz );
     pz[ sz ] = NUL;
 
-    rename( pCurFp->pzOutName, pz );
+    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+        fprintf( pfTrace, "renaming %s to %s\n",  pCurFp->pzOutName, pz);
+    rename(pCurFp->pzOutName, pz);
     if ((pCurFp->flags & FPF_STATIC_NM) == 0)
         AGFREE( (void*)pCurFp->pzOutName );
     AGDUPSTR( pCurFp->pzOutName, pz, "file name" );
@@ -185,6 +188,9 @@ ag_scm_out_pop( SCM ret_contents )
         }
     }
 
+    if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
+        fputs("out-pop\n", pfTrace);
+
     outputDepth--;
     closeOutput( AG_FALSE );
     return res;
@@ -224,6 +230,10 @@ ag_scm_out_suspend( SCM suspName )
 
     pSuspended[ suspendCt-1 ].pzSuspendName = gh_scm2newstr( suspName, NULL );
     pSuspended[ suspendCt-1 ].pOutDesc      = pCurFp;
+    if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
+        fprintf(pfTrace, "suspended output to '%s'\n",
+                pSuspended[ suspendCt-1 ].pzSuspendName);
+
     pCurFp = pCurFp->pPrev;
     outputDepth--;
 
@@ -254,6 +264,8 @@ ag_scm_out_resume( SCM suspName )
             if (ix < --suspendCt)
                 pSuspended[ ix ] = pSuspended[ suspendCt ];
             ++outputDepth;
+            if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
+                fprintf(pfTrace, "resuming output to '%s'\n", pzName);
             return SCM_UNDEFINED;
         }
     }
@@ -265,6 +277,22 @@ ag_scm_out_resume( SCM suspName )
 }
 
 
+/*=gfunc out_emit_suspended
+ *
+ * what:   emit the text of suspended output
+ * exparg: suspName, A name tag of suspended output
+ * doc:
+ *  This function is equivalent to
+ *  @code{(begin (out-resume <name>) (out-pop #t))}
+=*/
+SCM
+ag_scm_out_emit_suspended( SCM suspName )
+{
+    (void)ag_scm_out_resume(suspName);
+    return ag_scm_out_pop(SCM_BOOL_T);
+}
+
+
 /*=gfunc ag_fprintf
  *
  * what:  format to autogen stream
@@ -385,6 +413,8 @@ ag_scm_out_push_add( SCM new_file )
     p->pzOutName = pzNewFile;
     outputDepth++;
     pCurFp       = p;
+    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+        fprintf(pfTrace, "appending output to '%s'\n", pzNewFile);
     return SCM_UNDEFINED;
 }
 
@@ -419,6 +449,8 @@ ag_scm_out_push_new( SCM new_file )
         pzNewFile[ sz ] = NUL;
         unlink( pzNewFile );
         addWriteAccess( pzNewFile );
+        if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+            fprintf(pfTrace, "creating output to '%s'\n", pzNewFile);
         p->pFile = fopen( pzNewFile, "a" FOPEN_BINARY_FLAG "+" );
     }
     else
@@ -526,6 +558,9 @@ ag_scm_out_switch( SCM new_file )
     tbuf.actime  = time( NULL );
     tbuf.modtime = outTime;
     utime( pCurFp->pzOutName, &tbuf );
+    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+        fprintf(pfTrace, "switching output from %s to '%s'\n",
+                pCurFp->pzOutName, pzNewFile);
     pCurFp->pzOutName = pzNewFile;  /* memory leak */
 
     return SCM_UNDEFINED;
@@ -705,8 +740,9 @@ ag_scm_make_header_guard(SCM name)
         lpz = opz;
         do  {
             *(scan_p++) = '_';
-            while ((! isalnum(*lpz)) && (*lpz != NUL))  lpz++;
-            while (isalnum(*lpz))   *(scan_p++) = toupper(*(lpz++));
+            while ((! IS_ALPHANUMERIC_CHAR(*lpz)) && (*lpz != NUL))  lpz++;
+            while (IS_ALPHANUMERIC_CHAR(*lpz))
+                *(scan_p++) = toupper(*(lpz++));
         } while (*lpz != NUL);
 
         memcpy(scan_p, grd, sizeof(grd));
