@@ -1,10 +1,10 @@
 
 /*
  *  expState.c
- *  $Id: expState.c,v 4.22 2007/08/05 17:09:50 bkorb Exp $
+ *  $Id: expState.c,v 4.25 2007/12/23 21:02:22 bkorb Exp $
  *
- *  Time-stamp:        "2007-07-04 11:19:46 bkorb"
- *  Last Committed:    $Date: 2007/08/05 17:09:50 $
+ *  Time-stamp:        "2007-12-23 12:49:15 bkorb"
+ *  Last Committed:    $Date: 2007/12/23 21:02:22 $
  *
  *  This module implements expression functions that
  *  query and get state information from AutoGen data.
@@ -253,10 +253,10 @@ str2int_ver( char* pz )
     while (--ix >= 0) {
         unsigned int v;
         val <<= VER_UNIT_SHIFT;
-        while (isspace(*pz))  pz++;
+        while (IS_WHITESPACE_CHAR(*pz))  pz++;
 
     next_number:
-        if (! isdigit(*pz)) break;
+        if (! IS_DEC_DIGIT_CHAR(*pz)) break;
         v = (unsigned int)strtoul(pz, &pz, 0) & ((1 << VER_UNIT_SHIFT) - 1);
         if (pz == NULL)
             break;
@@ -278,7 +278,7 @@ str2int_ver( char* pz )
             goto leave_str2int_ver;
 
         case '.':
-            if (! isdigit( *(++pz) ))
+            if (! IS_DEC_DIGIT_CHAR( *(++pz) ))
                 goto leave_str2int_ver;
             break;
         }
@@ -494,6 +494,76 @@ ag_scm_get( SCM agName, SCM altVal )
 }
 
 
+/*=gfunc get_c_name
+ *
+ * what:   get named value, mapped to C name syntax
+ *
+ * exparg: ag-name, name of AutoGen value
+ *
+ * doc:
+ *
+ *  Get the first string value associated with the name.  It will either
+ *  return the associated string value (if the name resolves), the alternate
+ *  value (if one is provided), or else the empty string.  The result is
+ *  passed through "string->c-name!".
+=*/
+SCM
+ag_scm_get_c_name(SCM agName)
+{
+    tDefEntry*  pE;
+    ag_bool     x;
+
+    if (! AG_SCM_STRING_P( agName ))
+         pE = NULL;
+    else pE = findDefEntry( ag_scm2zchars( agName, "ag value" ), &x );
+
+    if ((pE == NULL) || (pE->valType != VALTYP_TEXT))
+        return AG_SCM_STR02SCM(zNil);
+
+    return ag_scm_string_to_c_name_x( AG_SCM_STR02SCM( pE->val.pzText));
+}
+
+
+/*=gfunc get_up_name
+ *
+ * what:   get upper cased named value, mapped to C name syntax
+ *
+ * exparg: ag-name, name of AutoGen value
+ *
+ * doc:
+ *
+ *  Get the first string value associated with the name.  It will either
+ *  return the associated string value (if the name resolves), the alternate
+ *  value (if one is provided), or else the empty string.  The result is
+ *  passed through "string->c-name!" and "string->up-case!".
+=*/
+SCM
+ag_scm_get_up_name(SCM agName)
+{
+    return ag_scm_string_upcase_x( ag_scm_get_c_name( agName));
+}
+
+
+/*=gfunc get_down_name
+ *
+ * what:   get lower cased named value, mapped to C name syntax
+ *
+ * exparg: ag-name, name of AutoGen value
+ *
+ * doc:
+ *
+ *  Get the first string value associated with the name.  It will either
+ *  return the associated string value (if the name resolves), the alternate
+ *  value (if one is provided), or else the empty string.  The result is
+ *  passed through "string->c-name!" and "string->down-case!".
+=*/
+SCM
+ag_scm_get_down_name(SCM agName)
+{
+    return ag_scm_string_downcase_x( ag_scm_get_c_name( agName));
+}
+
+
 /*=gfunc high_lim
  *
  * what:   get highest value index
