@@ -1,31 +1,27 @@
 
 /*
- *  $Id: funcFor.c,v 4.17 2007/04/28 22:19:23 bkorb Exp $
+ *  $Id: funcFor.c,v 4.23 2007/12/03 01:34:24 bkorb Exp $
  *
- *  Time-stamp:        "2006-11-26 17:44:35 bkorb"
- *  Last Committed:    $Date: 2007/04/28 22:19:23 $
+ *  Time-stamp:        "2007-12-02 15:58:01 bkorb"
+ *  Last Committed:    $Date: 2007/12/03 01:34:24 $
  *
  *  This module implements the FOR text macro.
- */
-
-/*
- *  AutoGen copyright 1992-2007 Bruce Korb
  *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * AutoGen is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ * AutoGen is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #define ENTRY_END  INT_MAX
@@ -35,7 +31,7 @@ static tForState*  pFS;  /* Current "FOR" information (state) */
 tSCC zNoEnd[] = "%s ERROR:  FOR loop `%s' does not end\n";
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static ag_bool
 nextDefinition( ag_bool invert, tDefEntry** ppList );
 
@@ -510,7 +506,7 @@ load_ForIn( tCC* pzSrc, size_t srcLen, tTemplate* pT, tMacro* pMac )
      */
     pzSrc  += 2;
     srcLen -= 3;
-    while (isspace( *++pzSrc ))  srcLen--;
+    while (IS_WHITESPACE_CHAR(*++pzSrc))  srcLen--;
     if (*pzSrc == NUL)
         AG_ABEND_IN( pT, pMac, "FOR x IN ... has no list" );
 
@@ -542,7 +538,7 @@ load_ForIn( tCC* pzSrc, size_t srcLen, tTemplate* pT, tMacro* pMac )
             /*
              *  Clean up trailing commas
              */
-            while (isspace( *pz ))  pz++;
+            while (IS_WHITESPACE_CHAR(*pz))  pz++;
             if (*pz == ',')
                 pz++;
             break;
@@ -577,7 +573,7 @@ load_ForIn( tCC* pzSrc, size_t srcLen, tTemplate* pT, tMacro* pMac )
         /*
          *  Clean up trailing white space
          */
-        while (isspace( *pz ))  pz++;
+        while (IS_WHITESPACE_CHAR(*pz))  pz++;
 
         /*
          *  IF there is a previous entry, link its twin to this one.
@@ -693,6 +689,13 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
     tDefEntry*  pDef;
     int         loopCt;
 
+    /*
+     *  "funcPrivate" is used by the "FOR x IN ..." variation of the macro.
+     *  When parsed, a chain of text definitions are hung off of "funcPrivate".
+     *  "doForEach()" will then chase through the linked list of text
+     *  values.  This winds up being identical to [+ FOR var +] where
+     *  a list of "var" values has been set.
+     */
     if (pMac->funcPrivate != NULL)
         pDef = pMac->funcPrivate;
     else {
@@ -702,7 +705,7 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
                 fprintf( pfTrace, "FOR loop skipped - no definition for `%s'\n",
                          pT->pzTemplText + pMac->ozName );
 
-                if (OPT_VALUE_TRACE < TRACE_EVERYTHING)
+                if (OPT_VALUE_TRACE == TRACE_EVERYTHING)
                     fprintf( pfTrace, zFileLine, pT->pzTplFile, pMac->lineNo );
             }
 
@@ -710,6 +713,9 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
         }
     }
 
+    /*
+     *  Push the current FOR context onto a stack.
+     */
     if (++(forInfo.fi_depth) > forInfo.fi_alloc) {
         forInfo.fi_alloc += 5;
         if (forInfo.fi_data == NULL)
@@ -731,6 +737,9 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
                  pT->pzTemplText + pMac->ozName, pT->pzTplFile,
                  pMac->lineNo );
 
+    /*
+     *  Check for a FOR iterating based on scheme macros
+     */
     if (pT->pzTemplText[ pMac->ozText ] == '(') {
         pFS->for_from  = \
         pFS->for_to    = 0x7BAD0BAD;
@@ -741,6 +750,9 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
         loopCt = doForByStep( pT, pMac, pDef );
     }
     else {
+        /*
+         *  The FOR iterates over a list of definitions
+         */
         pFS->for_pzSep = pT->pzTemplText + pMac->ozText;
         loopCt = doForEach( pT, pMac, pDef );
     }
@@ -751,7 +763,7 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
         fprintf( pfTrace, "FOR %s repeated %d times\n",
                  pT->pzTemplText + pMac->ozName, loopCt );
 
-        if (OPT_VALUE_TRACE < TRACE_EVERYTHING)
+        if (OPT_VALUE_TRACE == TRACE_EVERYTHING)
             fprintf( pfTrace, zFileLine, pT->pzTplFile, pMac->lineNo );
     }
 
@@ -798,11 +810,11 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     pMac->ozName = pT->pNext - pT->pzTemplText;
     if (*pzSrc == '.') {
         *(pzCopy++) = *(pzSrc++);
-        if (! ISNAMECHAR( *pzSrc ))
+        if (! IS_VAR_FIRST_CHAR(*pzSrc))
             pzCopy--; /* force an error */
     }
 
-    while (ISNAMECHAR( *pzSrc )) *(pzCopy++) = *(pzSrc++);
+    while (IS_VALUE_NAME_CHAR(*pzSrc)) *(pzCopy++) = *(pzSrc++);
     *(pzCopy++) = NUL;
 
     if (pT->pzTemplText[ pMac->ozName ] == NUL)
@@ -811,7 +823,7 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     /*
      *  Skip space to the start of the text following the iterator name
      */
-    while (isspace( *pzSrc )) pzSrc++;
+    while (IS_WHITESPACE_CHAR(*pzSrc)) pzSrc++;
     srcLen -= pzSrc - (char*)pMac->ozText;
 
     /* * * * *
@@ -827,7 +839,7 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      *  FOR foo IN ...  -> no text, but we create an array of text values
      */
     else if (   (strneqvcmp( pzSrc, "in", 2 ) == 0)
-             && isspace( pzSrc[2] )) {
+             && IS_WHITESPACE_CHAR(pzSrc[2])) {
         load_ForIn( pzSrc, srcLen, pT, pMac );
     }
 
