@@ -1,25 +1,32 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sat Feb 17 12:50:05 PST 2007
+ * Generated Sun Dec 23 13:03:28 PST 2007
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
+
 #ifndef LOCAL
 #  define LOCAL extern
 #  define REDEF_LOCAL 1
 #else
 #  undef  REDEF_LOCAL
 #endif
-/*\n *  Extracted from agCgi.c\n */
+/*
+ *  Extracted from agCgi.c
+ */
 LOCAL void
 loadCgi( void );
 
-/*\n *  Extracted from agInit.c\n */
+/*
+ *  Extracted from agInit.c
+ */
 LOCAL void
 initialize( int arg_ct, char** arg_vec );
 
-/*\n *  Extracted from agShell.c\n */
+/*
+ *  Extracted from agShell.c
+ */
 LOCAL void
 closeServer( void );
 
@@ -37,7 +44,9 @@ openServerFP( tpfPair* pfPair, tCC** ppArgs );
 LOCAL char*
 runShell( char const*  pzCmd );
 
-/*\n *  Extracted from agUtils.c\n */
+/*
+ *  Extracted from agUtils.c
+ */
 LOCAL char*
 aprf( char const* pzFmt, ... );
 
@@ -59,7 +68,9 @@ skipScheme( tCC* pzSrc,  tCC* pzEnd );
 LOCAL tCC*
 skipExpression( tCC* pzSrc, size_t len );
 
-/*\n *  Extracted from autogen.c\n */
+/*
+ *  Extracted from autogen.c
+ */
 LOCAL void
 ag_abend_at( tCC* pzMsg
 #ifdef DEBUG_ENABLED
@@ -79,11 +90,15 @@ ao_free (void *p);
 LOCAL char *
 ao_strdup (char const * str);
 
-/*\n *  Extracted from defDirect.c\n */
+/*
+ *  Extracted from defDirect.c
+ */
 LOCAL char*
 processDirective( char* pzScan );
 
-/*\n *  Extracted from defFind.c\n */
+/*
+ *  Extracted from defFind.c
+ */
 LOCAL int
 canonicalizeName( char* pzD, char const* pzS, int srcLen );
 
@@ -93,14 +108,18 @@ findDefEntry( char* pzName, ag_bool* pIsIndexed );
 LOCAL tDefEntry**
 findEntryList( char* pzName );
 
-/*\n *  Extracted from defLex.c\n */
+/*
+ *  Extracted from defLex.c
+ */
 LOCAL te_dp_event
 yylex( void );
 
 LOCAL void
 yyerror( char* s );
 
-/*\n *  Extracted from defLoad.c\n */
+/*
+ *  Extracted from defLoad.c
+ */
 LOCAL void
 freeEntry( tDefEntry* pDE );
 
@@ -116,26 +135,36 @@ readDefines( void );
 LOCAL void
 unloadDefs( void );
 
-/*\n *  Extracted from expGuile.c\n */
+/*
+ *  Extracted from expGuile.c
+ */
 LOCAL teGuileType
 gh_type_e( SCM typ );
 
 LOCAL SCM
 ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line );
 
-/*\n *  Extracted from expOutput.c\n */
+/*
+ *  Extracted from expOutput.c
+ */
 LOCAL void
 removeWriteAccess( int fd );
 
-/*\n *  Extracted from expPrint.c\n */
+/*
+ *  Extracted from expPrint.c
+ */
 LOCAL SCM
 run_printf( char* pzFmt, int len, SCM alist );
 
-/*\n *  Extracted from funcDef.c\n */
+/*
+ *  Extracted from funcDef.c
+ */
 LOCAL void
 parseMacroArgs( tTemplate* pT, tMacro* pMac );
 
-/*\n *  Extracted from funcEval.c\n */
+/*
+ *  Extracted from funcEval.c
+ */
 LOCAL tCC*
 resolveSCM( SCM s );
 
@@ -145,14 +174,18 @@ evalExpression( ag_bool* pMustFree );
 LOCAL SCM
 eval( char const* pzExpr );
 
-/*\n *  Extracted from loadPseudo.c\n */
+/*
+ *  Extracted from loadPseudo.c
+ */
 LOCAL tCC*
-doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo );
+doSuffixSpec(tCC * const pzData, tCC* pzFileName, int lineNo);
 
 LOCAL tCC*
 loadPseudoMacro( tCC* pzData, tCC* pzFileName );
 
-/*\n *  Extracted from tpLoad.c\n */
+/*
+ *  Extracted from tpLoad.c
+ */
 LOCAL tTemplate*
 findTemplate( tCC* pzTemplName );
 
@@ -168,16 +201,23 @@ unloadTemplate( tTemplate* pT );
 LOCAL void
 cleanup( tTemplate* pTF );
 
-/*\n *  Extracted from tpParse.c\n */
+/*
+ *  Extracted from tpParse.c
+ */
 LOCAL tMacro*
 parseTemplate( tMacro* pM, tCC** ppzText );
 
-/*\n *  Extracted from tpProcess.c\n */
+/*
+ *  Extracted from tpProcess.c
+ */
 LOCAL void
 generateBlock( tTemplate*   pT,
                tMacro*      pMac,
                tMacro*      pEnd );
 
+LOCAL tOutSpec *
+nextOutSpec(tOutSpec * pOS);
+
 LOCAL void
 processTemplate( tTemplate* pTF );
 
