@@ -2,10 +2,10 @@
 /*
  *  tpParse.c
  *
- *  $Id: tpParse.c,v 4.14 2007/07/04 20:51:12 bkorb Exp $
+ *  $Id: tpParse.c,v 4.18 2007/12/02 22:42:00 bkorb Exp $
  *
- * Time-stamp:        "2007-07-04 11:31:58 bkorb"
- * Last Committed:    $Date: 2007/07/04 20:51:12 $
+ * Time-stamp:        "2007-12-02 12:39:12 bkorb"
+ * Last Committed:    $Date: 2007/12/02 22:42:00 $
  *
  *  This module will load a template and return a template structure.
  *
@@ -33,7 +33,7 @@ tSCC zTDef[] = "%-10s (%d) line %d end=%d, strlen=%d\n";
 #endif
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static teFuncType
 whichFunc( tCC** ppzScan );
 
@@ -57,10 +57,10 @@ whichFunc( tCC** ppzScan )
     int           cmp;
 
     /*
-     *  IF the name starts with a punctuation,
-     *  THEN we will use strncmp instead of strneqvcmp to test values.
+     *  IF the name starts with a punctuation, then it is some sort of
+     *  alias.  Find the function in the alias portion of the table.
      */
-    if (ispunct( *pzFuncName )) {
+    if (IS_PUNCTUATION_CHAR(*pzFuncName)) {
         hi = FUNC_ALIAS_HIGH_INDEX;
         lo = FUNC_ALIAS_LOW_INDEX;
         do  {
@@ -83,7 +83,7 @@ whichFunc( tCC** ppzScan )
         return FTYP_BOGUS;
     }
 
-    if (! isalpha( *pzFuncName ))
+    if (! IS_VAR_FIRST_CHAR(*pzFuncName))
         return FTYP_BOGUS;
 
     hi = FUNC_NAMES_HIGH_INDEX;
@@ -97,7 +97,7 @@ whichFunc( tCC** ppzScan )
             /*
              *  Make sure we matched to the end of the token.
              */
-            if (ISNAMECHAR( pzFuncName[pNT->cmpLen] ))
+            if (IS_VARIABLE_NAME_CHAR(pzFuncName[pNT->cmpLen]))
                 break;
 
             /*
@@ -118,8 +118,14 @@ whichFunc( tCC** ppzScan )
     pCurMacro->ozName = (pCurTemplate->pNext - pCurTemplate->pzTemplText);
     {
         char* pzCopy = pCurTemplate->pNext;
-        while (ISNAMECHAR( *pzFuncName ))
+        while (IS_VALUE_NAME_CHAR(*pzFuncName))
             *(pzCopy++) = *(pzFuncName++);
+        /*
+         *  Names are allowed to contain colons, but not end with them.
+         */
+        if (pzCopy[-1] == ':')
+            pzCopy--, pzFuncName--;
+
         *(pzCopy++) = NUL;
         *ppzScan = pzFuncName;
         pCurTemplate->pNext = pzCopy;
@@ -146,7 +152,7 @@ findMacroEnd( tCC** ppzMark )
     /*
      *  Set our pointers to the start of the macro text
      */
-    while (isspace( *pzMark )) {
+    while (IS_WHITESPACE_CHAR(*pzMark)) {
         if (*(pzMark++) == '\n')
             templLineNo++;
     }
@@ -212,11 +218,11 @@ nextMacroStart( tCC* pz, tMacro** ppM, tTemplate* pTpl )
 #if defined(DEBUG_ENABLED)
     if (HAVE_OPT( SHOW_DEFS )) {
         int ct = tplNestLevel;
-        fprintf( pfTrace, "%3d ", pM - pTpl->aMacros );
+        fprintf(pfTrace, "%3u ", (unsigned int)(pM - pTpl->aMacros));
         do { fputs( "  ", pfTrace ); } while (--ct > 0);
 
-        fprintf( pfTrace, zTDef, apzFuncNames[ FTYP_TEXT ], FTYP_TEXT,
-                 pM->lineNo, pM->endIndex, pzEnd - pz );
+        fprintf(pfTrace, zTDef, apzFuncNames[ FTYP_TEXT ], FTYP_TEXT,
+                pM->lineNo, pM->endIndex, (unsigned int)(pzEnd - pz));
     }
 #endif
 
@@ -249,7 +255,7 @@ parseTemplate( tMacro* pM, tCC** ppzText )
         int ct = tplNestLevel;
         tMacro* pPm = pM-1;
 
-        fprintf( pfTrace, "%3d ", pPm - pTpl->aMacros );
+        fprintf(pfTrace, "%3u ", (unsigned int)(pPm - pTpl->aMacros));
         do { fputs( "  ", pfTrace ); } while (--ct > 0);
 
         fprintf( pfTrace, zTUndef, apzFuncNames[ pPm->funcCode ],
@@ -293,8 +299,11 @@ parseTemplate( tMacro* pM, tCC** ppzText )
             /*
              *  Strip white space from the macro
              */
-            while ((pzMark < pzMacEnd) && isspace( *pzMark ))  pzMark++;
-            while ((pzMacEnd > pzMark) && isspace( pzMacEnd[-1] )) pzMacEnd--;
+            while ((pzMark < pzMacEnd) && IS_WHITESPACE_CHAR(*pzMark))
+                pzMark++;
+            while ((pzMacEnd > pzMark) && IS_WHITESPACE_CHAR(pzMacEnd[-1]))
+                pzMacEnd--;
+
             if (pzMark != pzMacEnd) {
                 pM->ozText = (uintptr_t)pzMark;
                 pM->res    = (long)(pzMacEnd - pzMark);
@@ -316,7 +325,7 @@ parseTemplate( tMacro* pM, tCC** ppzText )
              *  from the end macro marker to EOL.  Anything else on the line
              *  will suppress the feature.
              */
-            while (isspace( *pz )) {
+            while (IS_WHITESPACE_CHAR(*pz)) {
                 if (*(pz++) == '\n') {
                     templLineNo++;
                     pzScan = pz;
@@ -331,7 +340,7 @@ parseTemplate( tMacro* pM, tCC** ppzText )
          *       will be non-NULL.
          */
         {
-            tMacro* pNM = (*(papLoadProc[ pM->funcCode ]))( pTpl, pM, &pzScan );
+            tMacro* pNM = (*(papLoadProc[ pM->funcCode ]))(pTpl, pM, &pzScan);
 
 #if defined(DEBUG_ENABLED)
             if (HAVE_OPT( SHOW_DEFS )) {
@@ -340,7 +349,8 @@ parseTemplate( tMacro* pM, tCC** ppzText )
                 int ct = tplNestLevel;
                 if (pM->funcCode == FTYP_BOGUS)
                      fputs( "    ", pfTrace );
-                else fprintf( pfTrace, "%3d ", pM - pTpl->aMacros );
+                else fprintf(pfTrace, "%3u ",
+                             (unsigned int)(pM - pTpl->aMacros));
 
                 do { fputs( "  ", pfTrace ); } while (--ct > 0);
 
@@ -354,7 +364,7 @@ parseTemplate( tMacro* pM, tCC** ppzText )
                         ? zNil
                         : (pTpl->pzTemplText + pM->ozText);
                     fprintf( pfTrace, zTDef, apzFuncNames[ ft ], pM->funcCode,
-                             ln, pM->endIndex, strlen( pz ));
+                             ln, pM->endIndex, (unsigned int)strlen(pz));
                 }
             }
 #endif
