@@ -1,7 +1,7 @@
 
 /*
- *  $Id: autoopts.c,v 4.29 2007/08/05 17:31:15 bkorb Exp $
- *  Time-stamp:      "2007-08-05 10:20:23 bkorb"
+ *  $Id: autoopts.c,v 4.31 2007/11/13 05:49:46 bkorb Exp $
+ *  Time-stamp:      "2007-11-12 20:35:53 bkorb"
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -418,7 +418,7 @@ shortOptionFind( tOptions* pOpts, uint_t optValue, tOptState* pOptState )
      *  THEN the result is the "option" itself and the
      *       option is the specially marked "number" option.
      */
-    if (  isdigit( optValue )
+    if (  IS_DEC_DIGIT_CHAR(optValue)
        && (pOpts->specOptIdx.number_option != NO_EQUIVALENT) ) {
         pOptState->pOD = \
         pRes           = pOpts->pOptDesc + pOpts->specOptIdx.number_option;
