@@ -1,60 +1,37 @@
 
 /*
- *  $Id: load.c,v 4.17 2007/01/18 05:32:13 bkorb Exp $
- *  Time-stamp:      "2007-01-17 16:46:42 bkorb"
+ *  $Id: load.c,v 4.24 2007/11/13 05:49:47 bkorb Exp $
+ *  Time-stamp:      "2007-11-12 20:38:32 bkorb"
  *
  *  This file contains the routines that deal with processing text strings
  *  for options, either from a NUL-terminated string passed in or from an
  *  rc/ini file.
- */
-
-/*
- *  Automated Options copyright 1992-2006 Bruce Korb
  *
- *  Automated Options is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoOpts, a companion to AutoGen.
+ *  AutoOpts is free software.
+ *  AutoOpts is copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  Automated Options is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  AutoOpts is available under any one of two licenses.  The license
+ *  in use must be one of these two and the choice is under the control
+ *  of the user of the license.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with Automated Options.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ *   The GNU Lesser General Public License, version 3 or later
+ *      See the files "COPYING.lgplv3" and "COPYING.gplv3"
  *
- * As a special exception, Bruce Korb gives permission for additional
- * uses of the text contained in his release of AutoOpts.
+ *   The Modified Berkeley Software Distribution License
+ *      See the file "COPYING.mbsd"
  *
- * The exception is that, if you link the AutoOpts library with other
- * files to produce an executable, this does not by itself cause the
- * resulting executable to be covered by the GNU General Public License.
- * Your use of that executable is in no way restricted on account of
- * linking the AutoOpts library code into it.
+ *  These files have the following md5sums:
  *
- * This exception does not however invalidate any other reasons why
- * the executable file might be covered by the GNU General Public License.
- *
- * This exception applies only to the code released by Bruce Korb under
- * the name AutoOpts.  If you copy code from other sources under the
- * General Public License into a copy of AutoOpts, as the General Public
- * License permits, the exception does not apply to the code that you add
- * in this way.  To avoid misleading anyone as to the status of such
- * modified files, you must delete this exception notice from them.
- *
- * If you write modifications of your own for AutoOpts, it is your choice
- * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.
+ *  239588c55c22c60ffe159946a760a33e pkg/libopts/COPYING.gplv3
+ *  fa82ca978890795162346e661b47161a pkg/libopts/COPYING.lgplv3
+ *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
  */
 
 tOptionLoadMode option_load_mode = OPTION_LOAD_UNCOOKED;
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static ag_bool
 insertProgramPath(
     char*   pzBuf,
@@ -99,8 +76,11 @@ assembleArgValue( char* pzTxt, tOptionLoadMode mode );
  *  @code{$$} is replaced with the directory name of the @code{pzProgPath},
  *  searching @code{$PATH} if necessary.
  *  @*
+ *  @code{$@} is replaced with the AutoGen package data installation directory
+ *  (aka @code{pkgdatadir}).
+ *  @*
  *  @code{$NAME} is replaced by the contents of the @code{NAME} environment
- *  variable.
+ *  variable.  If not found, the search fails.
  *
  *  Please note: both @code{$$} and @code{$NAME} must be at the start of the
  *     @code{pzName} string and must either be the entire string or be followed
@@ -110,8 +90,11 @@ assembleArgValue( char* pzTxt, tOptionLoadMode mode );
  *       @*
  *       @bullet{} The input name exceeds @code{bufSize} bytes.
  *       @*
- *       @bullet{} @code{$$} or @code{$NAME} is not the full string and
- *                 the next character is not '/'.
+ *       @bullet{} @code{$$}, @code{$@@} or @code{$NAME} is not the full string
+ *                 and the next character is not '/'.
+ *       @*
+ *       @bullet{} libopts was built without PKGDATADIR defined and @code{$@@}
+ *                 was specified.
  *       @*
  *       @bullet{} @code{NAME} is not a known environment variable
  *       @*
@@ -125,9 +108,17 @@ optionMakePath(
     tCC*    pzName,
     tCC*    pzProgPath )
 {
+    size_t  name_len = strlen( pzName );
+
+#   ifndef PKGDATADIR
+#     define PKGDATADIR ""
+#   endif
+
+    tSCC    pkgdatadir[] = PKGDATADIR;
+
     ag_bool res = AG_TRUE;
 
-    if (bufSize <= strlen( pzName ))
+    if (bufSize <= name_len)
         return AG_FALSE;
 
     /*
@@ -151,10 +142,28 @@ optionMakePath(
      *  it must start with "$$/".  In either event, replace the "$$"
      *  with the path to the executable and append a "/" character.
      */
-    else if (pzName[1] == '$')
+    else switch (pzName[1]) {
+    case NUL:
+        return AG_FALSE;
+
+    case '$':
         res = insertProgramPath( pzBuf, bufSize, pzName, pzProgPath );
-    else
+        break;
+
+    case '@':
+        if (pkgdatadir[0] == NUL)
+            return AG_FALSE;
+
+        if (name_len + sizeof (pkgdatadir) > bufSize)
+            return AG_FALSE;
+
+        strcpy(pzBuf, pkgdatadir);
+        strcpy(pzBuf + sizeof(pkgdatadir) - 1, pzName + 2);
+        break;
+
+    default:
         res = insertEnvVal( pzBuf, bufSize, pzName, pzProgPath );
+    }
 
     if (! res)
         return AG_FALSE;
@@ -245,7 +254,7 @@ insertProgramPath(
      *  allocated and we need to deallocate it.
      */
     if (pzPath != pzProgPath)
-        free( (void*)pzPath );
+        AGFREE(pzPath);
     return AG_TRUE;
 }
 
@@ -261,7 +270,7 @@ insertEnvVal(
 
     for (;;) {
         int ch = (int)*++pzName;
-        if (! ISNAMECHAR( ch ))
+        if (! IS_VALUE_NAME_CHAR(ch))
             break;
         *(pzDir++) = (char)ch;
     }
@@ -295,16 +304,16 @@ mungeString( char* pzTxt, tOptionLoadMode mode )
     if (mode == OPTION_LOAD_KEEP)
         return;
 
-    if (isspace( (int)*pzTxt )) {
+    if (IS_WHITESPACE_CHAR(*pzTxt)) {
         char* pzS = pzTxt;
         char* pzD = pzTxt;
-        while (isspace( (int)*++pzS ))  ;
+        while (IS_WHITESPACE_CHAR(*++pzS))  ;
         while ((*(pzD++) = *(pzS++)) != NUL)   ;
         pzE = pzD-1;
     } else
         pzE = pzTxt + strlen( pzTxt );
 
-    while ((pzE > pzTxt) && isspace( (int)pzE[-1] ))  pzE--;
+    while ((pzE > pzTxt) && IS_WHITESPACE_CHAR(pzE[-1]))  pzE--;
     *pzE = NUL;
 
     if (mode == OPTION_LOAD_UNCOOKED)
@@ -354,11 +363,11 @@ assembleArgValue( char* pzTxt, tOptionLoadMode mode )
      *  because we'll have to skip over an immediately following ':' or '='
      *  (and the white space following *that*).
      */
-    space_break = isspace((int)*pzEnd);
+    space_break = IS_WHITESPACE_CHAR(*pzEnd);
     *(pzEnd++) = NUL;
-    while (isspace((int)*pzEnd))  pzEnd++;
+    while (IS_WHITESPACE_CHAR(*pzEnd))  pzEnd++;
     if (space_break && ((*pzEnd == ':') || (*pzEnd == '=')))
-        while (isspace((int)*++pzEnd))  ;
+        while (IS_WHITESPACE_CHAR(*++pzEnd))  ;
 
     return pzEnd;
 }
@@ -378,7 +387,7 @@ loadOptionLine(
     tDirection  direction,
     tOptionLoadMode   load_mode )
 {
-    while (isspace( (int)*pzLine ))  pzLine++;
+    while (IS_WHITESPACE_CHAR(*pzLine))  pzLine++;
 
     {
         char* pzArg = assembleArgValue( pzLine, load_mode );
