@@ -1,26 +1,28 @@
 /*
  *  This file defines the string_tokenize interface
- * Time-stamp:      "2005-02-23 14:00:09 bkorb"
+ * Time-stamp:      "2007-11-12 20:40:36 bkorb"
  *
- *  string_tokenize copyright 2005 Bruce Korb
+ *  This file is part of AutoOpts, a companion to AutoGen.
+ *  AutoOpts is free software.
+ *  AutoOpts is copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  string_tokenize is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) any later version.
+ *  AutoOpts is available under any one of two licenses.  The license
+ *  in use must be one of these two and the choice is under the control
+ *  of the user of the license.
  *
- *  string_tokenize is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
+ *   The GNU Lesser General Public License, version 3 or later
+ *      See the files "COPYING.lgplv3" and "COPYING.gplv3"
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with string_tokenize; if not, write to:
- *             The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *   The Modified Berkeley Software Distribution License
+ *      See the file "COPYING.mbsd"
+ *
+ *  These files have the following md5sums:
+ *
+ *  239588c55c22c60ffe159946a760a33e pkg/libopts/COPYING.gplv3
+ *  fa82ca978890795162346e661b47161a pkg/libopts/COPYING.lgplv3
+ *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
  */
-#include <ctype.h>
+
 #include <errno.h>
 #include <stdlib.h>
 
@@ -28,16 +30,16 @@
 #define ch_t   unsigned char
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static void
-copy_cooked( ch_t** ppDest, cc_t** ppSrc );
+copy_cooked( ch_t** ppDest, char const ** ppSrc );
 
 static void
-copy_raw( ch_t** ppDest, cc_t** ppSrc );
+copy_raw( ch_t** ppDest, char const ** ppSrc );
 /* = = = END-STATIC-FORWARD = = = */
 
 static void
-copy_cooked( ch_t** ppDest, cc_t** ppSrc )
+copy_cooked( ch_t** ppDest, char const ** ppSrc )
 {
     ch_t* pDest = (ch_t*)*ppDest;
     const ch_t* pSrc  = (const ch_t*)(*ppSrc + 1);
@@ -48,7 +50,7 @@ copy_cooked( ch_t** ppDest, cc_t** ppSrc )
         case NUL:   *ppSrc = NULL; return;
         case '"':   goto done;
         case '\\':
-            pSrc += ao_string_cook_escape_char( pSrc, &ch, 0x7F );
+            pSrc += ao_string_cook_escape_char( (char*)pSrc, (char*)&ch, 0x7F );
             if (ch == 0x7F)
                 break;
             /* FALLTHROUGH */
@@ -60,15 +62,15 @@ copy_cooked( ch_t** ppDest, cc_t** ppSrc )
 
  done:
     *ppDest = (ch_t*)pDest; /* next spot for storing character */
-    *ppSrc  = (ch_t*)pSrc;  /* char following closing quote    */
+    *ppSrc  = (char const *)pSrc;  /* char following closing quote    */
 }
 
 
 static void
-copy_raw( ch_t** ppDest, cc_t** ppSrc )
+copy_raw( ch_t** ppDest, char const ** ppSrc )
 {
     ch_t* pDest = *ppDest;
-    cc_t* pSrc  = *ppSrc + 1;
+    cc_t* pSrc  = (cc_t*) (*ppSrc + 1);
 
     for (;;) {
         ch_t ch = *(pSrc++);
@@ -108,7 +110,7 @@ copy_raw( ch_t** ppDest, cc_t** ppSrc )
 
  done:
     *ppDest = pDest; /* next spot for storing character */
-    *ppSrc  = pSrc;  /* char following closing quote    */
+    *ppSrc  = (char const *) pSrc;  /* char following closing quote    */
 }
 
 
@@ -116,7 +118,7 @@ copy_raw( ch_t** ppDest, cc_t** ppSrc )
  *
  * what: tokenize an input string
  *
- * arg:  + const char* + string + string to be tokenized +
+ * arg:  + char const* + string + string to be tokenized +
  *
  * ret_type:  token_list_t*
  * ret_desc:  pointer to a structure that lists each token
@@ -178,7 +180,7 @@ copy_raw( ch_t** ppDest, cc_t** ppSrc )
  *  @end itemize
 =*/
 token_list_t*
-ao_string_tokenize( const char* str )
+ao_string_tokenize( char const* str )
 {
     int max_token_ct = 1; /* allow for trailing NUL on string */
     token_list_t* res;
@@ -189,7 +191,7 @@ ao_string_tokenize( const char* str )
      *  Trim leading white space.  Use "ENOENT" and a NULL return to indicate
      *  an empty string was passed.
      */
-    while (isspace( *str ))  str++;
+    while (IS_WHITESPACE_CHAR(*str))  str++;
     if (*str == NUL) {
     bogus_str:
         errno = ENOENT;
@@ -206,9 +208,9 @@ ao_string_tokenize( const char* str )
 
         do {
             max_token_ct++;
-            while (! isspace( *++pz ))
+            while (! IS_WHITESPACE_CHAR(*++pz))
                 if (*pz == NUL) goto found_nul;
-            while (isspace( *pz ))  pz++;
+            while (IS_WHITESPACE_CHAR(*pz))  pz++;
         } while (*pz != NUL);
 
     found_nul:
@@ -231,33 +233,33 @@ ao_string_tokenize( const char* str )
         do  {
             res->tkn_list[ res->tkn_ct++ ] = pzDest;
             for (;;) {
-                char ch = *str;
-                if (isspace( ch )) {
+                int ch = (ch_t)*str;
+                if (IS_WHITESPACE_CHAR(ch)) {
                 found_white_space:
-                    while (isspace( *++str ))  ;
+                    while (IS_WHITESPACE_CHAR(*++str))  ;
                     break;
                 }
 
                 switch (ch) {
                 case '"':
-                    copy_cooked( &pzDest, (cc_t**)&str );
+                    copy_cooked( &pzDest, &str );
                     if (str == NULL) {
                         free(res);
                         errno = EINVAL;
                         return NULL;
                     }
-                    if (isspace( *str ))
+                    if (IS_WHITESPACE_CHAR(*str))
                         goto found_white_space;
                     break;
 
                 case '\'':
-                    copy_raw( &pzDest, (cc_t**)&str );
+                    copy_raw( &pzDest, &str );
                     if (str == NULL) {
                         free(res);
                         errno = EINVAL;
                         return NULL;
                     }
-                    if (isspace( *str ))
+                    if (IS_WHITESPACE_CHAR(*str))
                         goto found_white_space;
                     break;
 
@@ -316,7 +318,6 @@ main( int argc, char** argv )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of autoopts/tokenize.c */
